.. py:module:: Orange.statistics

###########################
Statistics (``statistics``)
###########################

Orange provides several modules for computing statistics from the
data: basic statistics, like minimal, maximal and averages values of a
variable on a dataset, distributions (expressed as relative
frequencies) of discrete and continuous variables, and contingency
tables of pairs of variables.

.. toctree::
   :maxdepth: 1

   Orange.statistics.basic
   Orange.statistics.contingency
   Orange.statistics.distribution
   Orange.statistics.estimate
